<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// 0
'0_URL' => 'http://listes.rezo.net/mailman/listinfo/spip-dev',
'0_langue' => 'Portugu&ecirc;s do Brasil [pt_br]',
'0_liste' => 'spip-dev@rezo.net',
'0_mainteneur' => 'ricardo@calepino.com',

// A
'access_interface_graphique' => 'Voltar para a interface gr&aacute;fica completa',
'access_mode_texte' => 'Exibir a interface textual simplificada',
'admin_debug' => 'depurar',
'admin_modifier_article' => 'Editar esta mat&eacute;ria',
'admin_modifier_auteur' => 'Editar este autor',
'admin_modifier_breve' => 'Editar esta nota',
'admin_modifier_mot' => 'Editar esta palavra-chave',
'admin_modifier_rubrique' => 'Editar esta se&ccedil;&atilde;o',
'admin_recalculer' => 'Atualizar esta p&aacute;gina',
'afficher_trad' => 'exibir as tradu&ccedil;&otilde;es',
'alerte_maj_impossible' => 'Aten&ccedil;&atilde;o! A atualiza&ccedil;&atilde;o da base de dados SQL para a vers&atilde;o @version@ n&atilde;o &eacute; poss&iacute;vel, provavelmente por problema de direitos de edi&ccedil;&atilde;o na base de dados. Por favor, contate o seu provedor de hospedagem.',
'alerte_modif_info_concourante' => 'ATEN&Ccedil;&Atilde;O: Esta informa&ccedil;&atilde;o foi alterada por outra pessoa. O valor atual &eacute;:',
'analyse_xml' => 'Analisar XML',
'annuler' => 'Cancelar',
'antispam_champ_vide' => 'Deixe, por favor, este campo vazio:',
'articles_recents' => 'Mat&eacute;rias mais recentes',
'avis_archive_incorrect' => 'a c&oacute;pia de seguran&ccedil;a n&atilde;o &eacute; um arquivo do SPIP',
'avis_archive_invalide' => 'a c&oacute;pia de seguran&ccedil;a n&atilde;o &eacute; v&aacute;lida',
'avis_attention' => 'ATEN&Ccedil;&Atilde;O!',
'avis_champ_incorrect_type_objet' => 'Nome de campo incorreto @name@ para objeto do tipo @type@',
'avis_colonne_inexistante' => 'A coluna @col@ n&atilde;o existe',
'avis_echec_syndication_01' => 'A sindica&ccedil;&atilde;o falhou: o backend informado &eacute; indecifr&aacute;vel ou n&atilde;o prop&otilde;e nenhuma mat&eacute;ria.',
'avis_echec_syndication_02' => 'A sindica&ccedil;&atilde;o falhou: n&atilde;o foi poss&iacute;vel acessar o backend deste site.',
'avis_erreur' => 'Erro: ver abaixo',
'avis_erreur_connexion' => 'Erro de conex&atilde;o',
'avis_erreur_cookie' => 'problema de cookie',
'avis_erreur_fonction_contexte' => 'Erro de programa&ccedil;&atilde;o. Esta fun&ccedil;&atilde;o n&atilde;o deve ser chamada neste contexto.',
'avis_erreur_mysql' => 'Erro SQL',
'avis_erreur_sauvegarde' => 'Erro na c&oacute;pia de seguran&ccedil;a (@type@ @id_objet@) !',
'avis_erreur_visiteur' => 'Problema de acesso ao espa&ccedil;o privado',

// B
'barre_a_accent_grave' => 'Inserir um A mai&uacute;sculo com acento grave',
'barre_aide' => 'utilize os atalhos tipogr&aacute;ficos para enriquecer o seu layout',
'barre_e_accent_aigu' => 'Inserir um E mai&uacute;sculo com acento agudo',
'barre_eo' => 'Inserir um OE contra&iacute;do',
'barre_eo_maj' => 'Inserir um OE contra&iacute;do mai&uacute;sculo',
'barre_euro' => 'Inserir o s&iacute;mbolo &euro; (euro)',
'barre_gras' => 'Escrever em {{negrito}}',
'barre_guillemets' => 'envolver em "aspas"',
'barre_guillemets_simples' => 'Envolver em \'plicas\'',
'barre_intertitre' => 'Transformar em {{{entret&iacute;tulo}}}',
'barre_italic' => 'Escrever em {it&aacute;lico}',
'barre_lien' => 'Transformar em [link hipertexto->http://...]',
'barre_lien_input' => 'Informe o endere&ccedil;o do seu link (voc&ecirc; pode informar um endere&ccedil;o web do tipo http://www.monsite/com ou simplesmente informar o n&uacute;mero de uma mat&eacute;ria deste site.',
'barre_note' => 'Transformar em [[Nota de p&eacute; de p&aacute;gina]]',
'barre_paragraphe' => 'Criar um par&aacute;grafo',
'barre_quote' => '<quote>Citar uma mensagem</quote>',
'bouton_ajouter_document' => 'Incluir um documento',
'bouton_ajouter_image' => 'Incluir uma imagem',
'bouton_ajouter_image_document' => 'Incluir uma imagem ou um documento',
'bouton_changer' => 'Alterar',
'bouton_chercher' => 'Procurar',
'bouton_choisir' => 'Escolher',
'bouton_download' => 'Transferir',
'bouton_enregistrer' => 'Gravar',
'bouton_radio_desactiver_messagerie_interne' => 'Desativar o sistema interno de mensagens',
'bouton_radio_envoi_annonces' => 'Enviar os avisos editoriais',
'bouton_radio_non_envoi_annonces' => 'N&atilde;o enviar os avisos',
'bouton_radio_non_envoi_liste_nouveautes' => 'N&atilde;o enviar a lista de novidades',
'bouton_recharger_page' => 'atualizar esta p&aacute;gina',
'bouton_telecharger' => 'Transferir',
'bouton_valider' => 'Validar',

// C
'cal_apresmidi' => 'tarde',
'cal_jour_entier' => 'dia todo',
'cal_matin' => 'manh&atilde;',
'cal_par_jour' => 'calend&aacute;rio por dia',
'cal_par_mois' => 'calend&aacute;rio por m&ecirc;s',
'cal_par_semaine' => 'calend&aacute;rio por semana',
'choix_couleur_interface' => 'c&ocirc;r',
'choix_interface' => 'escolha da interface',
'colonne' => 'Coluna',
'confirm_changer_statut' => 'Aten&ccedil;&atilde;o, voc&ecirc; solicitou a altera&ccedil;&atilde;o de status deste elemento. Deseja continuar?',
'correcte' => 'correta',

// D
'date_aujourdhui' => 'hoje',
'date_avant_jc' => 'a.C.',
'date_dans' => 'entre @delai@',
'date_de_mois_1' => '@j@ de @nommois@',
'date_de_mois_10' => '@j@ de @nommois@',
'date_de_mois_11' => '@j@ de @nommois@',
'date_de_mois_12' => '@j@ de @nommois@',
'date_de_mois_2' => '@j@ de @nommois@',
'date_de_mois_3' => '@j@ de @nommois@',
'date_de_mois_4' => '@j@ de @nommois@',
'date_de_mois_5' => '@j@ de @nommois@',
'date_de_mois_6' => '@j@ de @nommois@',
'date_de_mois_7' => '@j@ de @nommois@',
'date_de_mois_8' => '@j@ de @nommois@',
'date_de_mois_9' => '@j@ de @nommois@',
'date_demain' => 'amanh&atilde;',
'date_fmt_heures_minutes' => '@h@h@m@min',
'date_fmt_jour_heure' => '@jour@ - @heure@',
'date_fmt_jour_mois' => '@jour@ de @nommois@',
'date_fmt_jour_mois_annee' => '@jour@ de @nommois@ de @annee@',
'date_fmt_mois_annee' => '@nommois@ de @annee@',
'date_fmt_nomjour_date' => '@nomjour@ de @date@',
'date_heures' => 'horas',
'date_hier' => 'ontem',
'date_il_y_a' => '&agrave; @delai@',
'date_jnum1' => '1&ordm;',
'date_jnum10' => '10',
'date_jnum11' => '11',
'date_jnum12' => '12',
'date_jnum13' => '13',
'date_jnum14' => '14',
'date_jnum15' => '15',
'date_jnum16' => '16',
'date_jnum17' => '17',
'date_jnum18' => '18',
'date_jnum19' => '19',
'date_jnum2' => '2',
'date_jnum20' => '20',
'date_jnum21' => '21',
'date_jnum22' => '22',
'date_jnum23' => '23',
'date_jnum24' => '24',
'date_jnum25' => '25',
'date_jnum26' => '26',
'date_jnum27' => '27',
'date_jnum28' => '28',
'date_jnum29' => '29',
'date_jnum3' => '3',
'date_jnum30' => '30',
'date_jnum31' => '31',
'date_jnum4' => '4',
'date_jnum5' => '5',
'date_jnum6' => '6',
'date_jnum7' => '7',
'date_jnum8' => '8',
'date_jnum9' => '9',
'date_jour_1' => 'domingo',
'date_jour_1_abbr' => 'dom.',
'date_jour_1_initiale' => 'd.',
'date_jour_2' => 'segunda-feira',
'date_jour_2_abbr' => 'seg.',
'date_jour_2_initiale' => 's.',
'date_jour_3' => 'ter&ccedil;a-feira',
'date_jour_3_abbr' => 'ter.',
'date_jour_3_initiale' => 't.',
'date_jour_4' => 'quarta-feira',
'date_jour_4_abbr' => 'quar.',
'date_jour_4_initiale' => 'q.',
'date_jour_5' => 'quinta-feira',
'date_jour_5_abbr' => 'quin.',
'date_jour_5_initiale' => 'q.',
'date_jour_6' => 'sexta-feira',
'date_jour_6_abbr' => 'sex.',
'date_jour_6_initiale' => 's.',
'date_jour_7' => 's&aacute;bado',
'date_jour_7_abbr' => 's&aacute;b.',
'date_jour_7_initiale' => 's.',
'date_jours' => 'dias',
'date_minutes' => 'minutos',
'date_mois' => 'meses',
'date_mois_1' => 'janeiro',
'date_mois_10' => 'outubro',
'date_mois_11' => 'novembro',
'date_mois_12' => 'dezembro',
'date_mois_2' => 'fevereiro',
'date_mois_3' => 'mar&ccedil;o',
'date_mois_4' => 'abril',
'date_mois_5' => 'maio',
'date_mois_6' => 'junho',
'date_mois_7' => 'julho',
'date_mois_8' => 'agosto',
'date_mois_9' => 'setembro',
'date_saison_1' => 'inverno',
'date_saison_2' => 'primavera',
'date_saison_3' => 'ver&atilde;o',
'date_saison_4' => 'outono',
'date_secondes' => 'segundos',
'date_semaines' => 'semanas',
'date_un_mois' => 'm&ecirc;s',
'date_une_heure' => 'hora',
'date_une_minute' => 'minuto',
'date_une_seconde' => 'segundo',
'date_une_semaine' => 'semana',
'dirs_commencer' => 'Para come&ccedil;ar realmente a instala&ccedil;&atilde;o',
'dirs_preliminaire' => 'Preliminar: <b>Configurar os direitos de acesso</b>',
'dirs_probleme_droits' => 'Problema com as permiss&otilde;es de acesso',
'dirs_repertoires_absents' => '<p><b>Os diret&oacute;rios a seguir n&atilde;o foram encontrados:</b></p><ul>@bad_dirs@.</ul>
<p>&Eacute; prov&aacute;vel que isto se deva a um problema de letras em mai&uacute;sculas e min&uacute;sculas.
Verifique se as mai&uacute;sculas e min&uacute;suculas destes diret&oacute;rios coincidem exatamente com o que est&aacute; sendo exibido abaixo; se este n&atilde;o for o caso, renomeie os diret&oacute;rios com o seu programa de FTP de modo a corrigir o erro.
<p>Uma v&ecirc;z feita esta manipula&ccedil;&atilde;o, voc&ecirc; poder&aacute; ',
'dirs_repertoires_suivants' => '<p><b>Os diret&oacute;rios a seguir n&atilde;o est&atilde;o acessiveis para leitura:</b></p><ul>@bad_dirs@.</ul>
<p>Para corrigir, utilize o seu programa de FTP para configurar os direitos de acesso de cada um destes diret&oacute;rios. O procedimento est&aacute; explicado em detalhes no guia de instala&ccedil;&atilde;o.</p>
<p>Uma v&ecirc;z feita esta altera&ccedil;&atilde;o, voc&ecirc; poder&aacute; ',
'double_occurrence' => 'Ocorr&ecirc;ncia dupla de @balise@',

// E
'en_cours' => 'em curso',
'entree_dimensions' => 'Dimens&otilde;es:',
'entree_titre_document' => 'T&iacute;tulo do documento:',
'entree_titre_image' => 'T&iacute;tulo da imagem:',
'envoi_via_le_site' => 'Envio pelo site',
'erreur' => 'Erro',
'erreur_balise_non_fermee' => '&Uacute;ltima tag em aberto:',
'erreur_texte' => 'erro(s)',
'etape' => 'Etapa',

// F
'fichier_introuvable' => 'Arquivo @fichier@ n&atilde;o encontrado',
'form_auteur_confirmation' => 'Confirme o seu endere&ccedil;o de e-mail',
'form_auteur_email_modifie' => 'O seu endere&ccedil;o de e-mail foi alterado.',
'form_auteur_envoi_mail_confirmation' => 'Uma mensagem de confirma&ccedil;&atilde;o acabou de ser enviada para @email@. Voc&ecirc; precisa entrar no endere&ccedil;o web mencionado na mensagem para validar o seu endere&ccedil;o de e-mail.',
'form_auteur_mail_confirmation' => 'Ol&aacute;,

Voc&ecirc; pediu para alterar o seu endere&ccedil;o de e-mail
Para confirmar o seu novo endere&ccedil;o, basta acessar o endere&ccedil;o abaixo (cas contr&aacute;rio, a sua solicita&ccedil;&atilde;o ser&aacute; ignorada):

    @url@
',
'form_deja_inscrit' => 'Voc&ecirc; j&aacute; est&aacute; inscrito.',
'form_email_non_valide' => 'Seu endere&ccedil;o de e-mail n&atilde;o &eacute; v&aacute;lido.',
'form_forum_access_refuse' => 'Voc&ecirc; n&atilde;o tem mais acesso a este site.',
'form_forum_bonjour' => 'Bom dia @nom@,',
'form_forum_email_deja_enregistre' => 'Este endere&ccedil;o de e-mail j&aacute; est&aacute; cadastrado, voc&ecirc; pode usar a sua senha habitual.',
'form_forum_identifiant_mail' => 'Seu novo login foi enviado por e-mail.',
'form_forum_identifiants' => 'Identificadores pessoais',
'form_forum_indiquer_nom_email' => 'Informe aqui o seu nome  endere&ccedil;o de e-mail. O seu identificador pessoal ser&aacute; enviado de imediato por correio eletr&ocirc;nico.',
'form_forum_login' => 'login:',
'form_forum_message_auto' => '(esta &eacute; uma mensagem autom&aacute;tica)',
'form_forum_pass' => 'senha:',
'form_forum_probleme_mail' => 'Problema de e-mail: o identificador n&atilde;o p&ocirc;de ser enviado.',
'form_forum_voici1' => 'Estes s&atilde;o os seus identificadores para que voc&ecirc; possa participar da vida do site "@nom_site_spip@" (@adresse_site@):',
'form_forum_voici2' => 'Estes s&atilde;o os seus identificadores para que voc&ecirc; possa propor mat&eacute;rias ao site "@nom_site_spip@" (@adresse_login@):',
'form_indiquer_email' => 'Por favor, informe o seu endere&ccedil;o de e-mail.',
'form_indiquer_nom' => 'Por favor, informe o seu nome.',
'form_indiquer_nom_site' => 'Por favor, informe o nome do seu site.',
'form_pet_adresse_site' => 'Endere&ccedil;o do seu site',
'form_pet_aucune_signature' => 'Nenhuma assinatura corresponde a este c&oacute;digo...',
'form_pet_confirmation' => 'Por favor, confirme a sua assinatura:',
'form_pet_deja_enregistre' => 'Este site j&aacute; est&aacute; cadastrado',
'form_pet_deja_signe' => 'Voc&ecirc; j&aacute; assinou este texto.',
'form_pet_envoi_mail_confirmation' => 'Um e-mail de confirma&ccedil;&atilde;o acabou de ser enviado para @email@. Voc&ecirc; dever&aacute; visitar o endere&ccedil;o web mencionado na mensagem para validar a sua assinatura.',
'form_pet_mail_confirmation' => 'Bom dia,

Voc&ecirc; pediu para assinar a peti&ccedil;&atilde;o:
@titre@.

Voc&ecirc; forneceu as informa&ccedil;&otilde;es abaixo:
    Nome: @nom_email@
    Site: @nom_site@ - @url_site@
    @message@

IMPORTANTE...
Para validar a sua assinatura, basta se conectar ao
endere&ccedil;o abaixo (caso contr&aacute;rio, seu pedido ser&aacute;
rejeitado):

    @url@


Obrigado por participar
',
'form_pet_message_commentaire' => 'Uma mensagem ou coment&aacute;rio?',
'form_pet_nom_site2' => 'Nome do seu website',
'form_pet_probleme_liens' => 'Por favor, retire os links hipertexto da sua mensagem.',
'form_pet_probleme_technique' => 'Problema t&eacute;cnico: as assinaturas est&atilde;o suspensas temporariamente.',
'form_pet_signature_pasprise' => 'Sua assinatura n&atilde;o foi computada.',
'form_pet_signature_validee' => 'Sua assinatura foi validada. Obrigado!',
'form_pet_site_deja_enregistre' => 'Este site j&aacute; est&aacute; cadastrado',
'form_pet_url_invalide' => 'O URL que voc&ecirc; informou n&atilde;o &eacute; v&aacute;lido.',
'form_pet_votre_email' => 'Seu endere&ccedil;o de e-mail',
'form_pet_votre_nom' => 'Seu nome ou apelido',
'form_pet_votre_site' => 'Se voc&ecirc; tem um website, voc&ecirc; pode inform&aacute;-lo abaixo',
'form_prop_confirmer_envoi' => 'Confirmar o envio',
'form_prop_description' => 'Descri&ccedil;&atilde;o / coment&aacute;rio',
'form_prop_enregistre' => 'Sua proposta foi cadastrada, ela aparecer&aacute; online ap&oacute;s ser validada pelos respons&aacute;veis deste site.',
'form_prop_envoyer' => 'Enviar uma mensagem',
'form_prop_indiquer_email' => 'Por favor, indique um endere&ccedil;o de e-mail v&aacute;lido',
'form_prop_indiquer_nom_site' => 'Por favor, informe o nome do site.',
'form_prop_indiquer_sujet' => 'Por favor, informe um assunto',
'form_prop_message_envoye' => 'Mensagem enviada',
'form_prop_nom_site' => 'Nome do site',
'form_prop_non_enregistre' => 'Sua proposta n&atilde;o foi cadastrada.',
'form_prop_sujet' => 'Assunto',
'form_prop_url_site' => 'Endere&ccedil;o (URL) do site',
'forum_acces_refuse' => 'Voc&ecirc; n&atilde;o tem mais acesso a estes f&oacute;runs.',
'forum_attention_dix_caracteres' => '<b>Aten&ccedil;&atilde;o!</b> Sua mensagem precisa ter pelo menos dez caracteres.',
'forum_attention_trois_caracteres' => '<b>Aten&ccedil;&atilde;o!</b> Seu t&iacute;tulo precisa ter pelo menos tr&ecirc;s caracteres.',
'forum_attention_trop_caracteres' => '<b>Aten&ccedil;&atilde;o!</b> sua mensagem &eacute; muito longa (@compte@ caracteres): para que ela seja gravada, ela n&atilde;o pode ultrapassar @max@ caracteres.',
'forum_avez_selectionne' => 'Voc&ecirc; selecionou:',
'forum_cliquer_retour' => 'Clique <a href=\'@retour_forum@\'>aqui</a> para continuar.',
'forum_forum' => 'f&oacute;rum',
'forum_info_modere' => 'Este f&oacute;rum &eacute; moderado a priori: a sua contribui&ccedil;&atilde;o s&oacute; ser&aacute; exibida ap&oacute;s ser validada por um administrador do site.',
'forum_lien_hyper' => '<b>Link hipertexto</b> (opcional)',
'forum_message_definitif' => 'Mensagem definitiva: enviar para o site',
'forum_message_trop_long' => 'Sua mensagem &eacute; muito longa. O tamanho m&aacute;imo &eacute; de 20000 caracteres.',
'forum_ne_repondez_pas' => 'N&atilde;o responda a esta mensagem e sim no f&oacute;rum com o endere&ccedil;o a seguir:',
'forum_non_inscrit' => 'Voc&ecirc; n&atilde;o est&aacute; inscrito, ou o endere&ccedil;o ou a senha est&atilde;o errados.',
'forum_page_url' => '(Se a sua mensagem se refere a uma mat&eacute;ria pubicada na Web, ou a uma p&aacute;gina fornecendo mais informa&ccedil;&otilde;es, por favor informe abaixo o t&iacute;tulo da p&aacute;gina e o seu endere&ccedil;o.)',
'forum_par_auteur' => 'por @auteur@',
'forum_poste_par' => 'Mensagem enviada @parauteur@ em seguimento da sua mat&eacute;ria.',
'forum_probleme_database' => 'Problema de base da dados: sua mensagem n&atilde;o foi cadastrada.',
'forum_qui_etes_vous' => '<b>Quem &eacute; voc&ecirc;?</b> (opcional)',
'forum_texte' => 'Texto da sua mensagem:',
'forum_titre' => 'T&iacute;tulo:',
'forum_titre_erreur' => 'Erro...',
'forum_url' => 'URL:',
'forum_valider' => 'Validar a sele&ccedil;&atilde;o',
'forum_voir_avant' => 'Ver esta mensagem antes de a enviar',
'forum_votre_email' => 'Seu endere&ccedil;o de e-mail:',
'forum_votre_nom' => 'Seu nome (ou apelido):',
'forum_vous_enregistrer' => 'Para participar deste f&oacute;rum, voc&ecirc; precisa se cadastrar previamente. Por favor, informe abaixo o identificador pessoal que lhe foi fornecido. Se voc&ecirc; n&atilde;o est&aacute; cadastrado, voc&ecirc; precisa',
'forum_vous_inscrire' => 'cadastrar-se.',

// I
'ical_texte_rss_articles' => 'O arquivo &laquo;backend&raquo; das mat&eacute;rias deste site encontra-se no endere&ccedil;o:',
'ical_texte_rss_articles2' => 'Voc&ecirc; pode tamb&eacute;m obter os arquivos &laquo;backend&raquo; para as mat&eacute;rias de cada se&ccedil;&atilde;o do site:',
'ical_texte_rss_breves' => 'Existe tamb&eacute;m um arquivo contendo as notas do site. Ao especificar um n&uacute;mero de se&ccedil;&atilde;o, voc&ecirc; obter&aacute; unicamente as natos dessa se&ccedil;&atilde;o.',
'icone_a_suivre' => 'Acompanhar',
'icone_admin_site' => 'Administra&ccedil;&atilde;o do site',
'icone_agenda' => 'Agenda',
'icone_aide_ligne' => 'Ajuda',
'icone_articles' => 'Mat&eacute;rias',
'icone_auteurs' => 'Autores',
'icone_breves' => 'Notas',
'icone_brouteur' => 'Navega&ccedil;&atilde;o r&aacute;pida',
'icone_configuration_site' => 'Configura&ccedil;&atilde;o',
'icone_configurer_site' => 'Configurar o seu site',
'icone_creer_nouvel_auteur' => 'Criar um novo autor',
'icone_creer_rubrique' => 'Criar uma se&ccedil;&atilde;o',
'icone_creer_sous_rubrique' => 'Criar uma subse&ccedil;&atilde;o',
'icone_deconnecter' => 'Desconectar-se',
'icone_discussions' => 'Discuss&otilde;es',
'icone_doc_rubrique' => 'Documentos das se&ccedil;&otilde;es',
'icone_ecrire_article' => 'Escrever uma nova mat&eacute;ria',
'icone_edition_site' => 'Edi&ccedil;&atilde;o',
'icone_forum_administrateur' => 'F&oacute;rum dos administradores',
'icone_forum_suivi' => 'Acompanhamento dos f&oacute;runs',
'icone_gestion_langues' => 'Gerenciamento de idiomas',
'icone_informations_personnelles' => 'Informa&ccedil;&otilde;es pessoais',
'icone_interface_complet' => 'interface completa',
'icone_interface_simple' => 'Interface simplificada',
'icone_maintenance_site' => 'Manuten&ccedil;&atilde;o do site',
'icone_messagerie_personnelle' => 'Mensagens pessoais',
'icone_mots_cles' => 'Palavras-chave',
'icone_nouvelle_breve' => 'Escrever uma nova nota',
'icone_repartition_actuelle' => 'Exibir a reparti&ccedil;&atilde;o atual',
'icone_repartition_debut' => 'Exibir a reparti&ccedil;&atilde;o ap&oacute;s o in&iacute;cio',
'icone_repartition_visites' => 'Reparti&ccedil;&atilde;o das visitas',
'icone_rubriques' => 'Se&ccedil;&otilde;es',
'icone_sauver_site' => 'Backup do site',
'icone_site_entier' => 'Todo o site',
'icone_sites_references' => 'Sites referenciados',
'icone_statistiques' => 'Estat&iacute;sticas do site',
'icone_statistiques_visites' => 'Estat&iacute;sticas',
'icone_suivi_activite' => 'Acompanhar a vida do site',
'icone_suivi_actualite' => 'Evolu&ccedil;&atilde;o do site',
'icone_suivi_forums' => 'Acompanhar / gerenciar os f&oacute;runs',
'icone_suivi_pettions' => 'Acompanhar / gerenciar as peti&ccedil;&otilde;es',
'icone_suivi_revisions' => 'Modifica&ccedil;&otilde;es das mat&eacute;rias',
'icone_supprimer_document' => 'Suprimir este documento',
'icone_supprimer_image' => 'Suprimir esta imagem',
'icone_supprimer_message' => 'Suprimir esta mensagem',
'icone_tous_articles' => 'Todas as suas mat&eacute;rias',
'icone_tous_auteur' => 'Todos os autores',
'icone_valider_message' => 'Validar esta mensagem',
'icone_visiter_site' => 'Visitar',
'icone_voir_en_ligne' => 'Ver online',
'image_tourner_180' => 'Rodar 180&deg;',
'image_tourner_droite' => 'Rodar 90&deg; &agrave; direita',
'image_tourner_gauche' => 'Rodar 90&deg; &agrave; esquerda',
'img_indisponible' => 'imagem indispon&iacute;vel',
'impossible' => 'imposs&iacute;vel',
'info_a_suivre' => 'ACOMPANHAR&raquo;',
'info_a_valider' => '[para validar]',
'info_acces_interdit' => 'Acesso interdito',
'info_acces_refuse' => 'Acesso recusado',
'info_action' => 'A&ccedil;&atilde;o: @action@',
'info_administrer_rubriques' => 'Voc&ecirc; pode administrar esta se&ccedil;&atilde;o e suas subse&ccedil;&otilde;es',
'info_adresse_non_indiquee' => 'Voc&ecirc; n&atilde;o informou o endere&ccedil;o a testar!',
'info_aide' => 'AJUDA:',
'info_ajouter_mot' => 'Incluir esta palavra',
'info_annonce' => 'AVISO',
'info_annonces_generales' => 'Avisos gerais:',
'info_article_propose' => 'Mat&eacute;ria proposta',
'info_article_publie' => 'Mat&eacute;ria publicada',
'info_article_redaction' => 'Mat&eacute;ria em fase de reda&ccedil;&atilde;o',
'info_article_refuse' => 'Mat&eacute;ria recusada',
'info_article_supprime' => 'Mat&eacute;ria suprimida',
'info_articles' => 'Mat&eacute;rias',
'info_articles_a_valider' => 'As mat&eacute;rias para validar',
'info_articles_nb' => '@nb@ mat&eacute;rias',
'info_articles_proposes' => 'Mat&eacute;rias propostas',
'info_articles_un' => '1 mat&eacute;ria',
'info_auteurs_nombre' => 'autor(es):',
'info_authentification_ftp' => 'Autentica&ccedil;&atilde;o (por FTP).',
'info_bloquer_lien' => 'bloquear este link',
'info_breves_02' => 'Notas',
'info_breves_2' => 'notas',
'info_breves_nb' => '@nb@ notas',
'info_breves_un' => '1 nota',
'info_breves_valider' => 'Notas para validar',
'info_connexion_refusee' => 'Conex&atilde;o recusada',
'info_contact_developpeur' => 'Por favor, contate um desenvolvedor.',
'info_contenance' => 'Este site cont&eacute;m:',
'info_contribution' => 'contribui&ccedil;&otilde;es de f&oacute;rum',
'info_copyright' => '@spip@ &eacute; um software livre distribu&iacute;do @lien_gpl@.',
'info_copyright_doc' => 'Para mais informa&ccedil;&otilde;es, veja o site <a href="@spipnet@">http://www.spip.net/</a>.',
'info_copyright_gpl' => 'sob licen&ccedil;a GPL',
'info_cours_edition' => 'Suas mat&eacute;rias em fase de reda&ccedil;&atilde;o',
'info_creer_repertoire' => 'Por favor, crie um arquivo ou diret&oacute;rio com o nome:',
'info_creer_repertoire_2' => 'dentro do subdiret&oacute;rio <b>@repertoire@</b>, e depois:',
'info_creer_vignette' => 'cria&ccedil;&atilde;o autom&aacute;tica do &iacute;cone',
'info_deplier' => 'Expandir',
'info_descriptif_nombre' => 'descri&ccedil;&atilde;o(&otilde;es):',
'info_description' => 'Resumo:',
'info_description_2' => 'Resumo:',
'info_dimension' => 'Dimens&otilde;es:',
'info_document' => 'Documento',
'info_document_indisponible' => 'Este documento n&atilde;o est&aacute; dispon&iacute;vel',
'info_documents' => 'Documentos',
'info_documents_nb' => '@nb@ documentos',
'info_documents_un' => '1 documento',
'info_echange_message' => 'O SPIP permite a troca de mensagens e a forma&ccedil;&atilde;o de f&oacute;runs de discuss&atilde;o privados entre os participantes do site. Voc&ecirc; pode ativar ou desativar esta funcionalidade.',
'info_ecire_message_prive' => 'Escrever uma mensagem privada',
'info_email_invalide' => 'Endere&ccedil;o de e-mail inv&aacute;lido.',
'info_en_cours_validation' => 'Suas mat&eacute;rias em fase de reda&ccedil;&atilde;o',
'info_en_ligne' => 'Atualmente online:',
'info_envoyer_message_prive' => 'Enviar uma mensagem privada a este autor',
'info_erreur_requete' => 'Erro na requisi&ccedil;&atilde;o:',
'info_erreur_squelette2' => 'Nenhum gabarito <b>@fichier@</b> est&aacute; dispon&iacute;vel...',
'info_erreur_systeme' => 'Erro do sistema (errno @errsys@)',
'info_erreur_systeme2' => '&Eacute; poss&iacute;vel que n&atilde;o haja espa&ccedil;o livre em disco, ou que a base de dados esteja corrompida.<br />
 <font color=\'red\'>Tente <a href=\'@script@\'>reparar a base</a>,
 ou contate o seu servi&ccedil;o de hospedagem.</font>',
'info_fini' => 'Terminou!',
'info_format_image' => 'Formatos das imagens que podem ser utilizados para criar os &iacute;cones @gd_formats@.',
'info_format_non_defini' => 'formato n&atilde;o definido',
'info_grand_ecran' => 'Alta resolu&ccedil;&atilde;o',
'info_image_aide' => 'AJUDA',
'info_image_process_titre' => 'M&eacute;todo de cria&ccedil;&atilde;o dos &iacute;cones',
'info_impossible_lire_page' => '<b>Erro!</b> Imposs&iacute;vel ler a p&aacute;gina <tt><html>@test_proxy@</html></tt> via proxy',
'info_inclusion_directe' => 'Inclus&atilde;o direta:',
'info_inclusion_vignette' => 'Inclus&atilde;o do &iacute;cone:',
'info_installation_systeme_publication' => 'Instala&ccedil;&atilde;o do sistema de publica&ccedil;&atilde;o...',
'info_installer_documents' => 'Voc&ecirc; pode instalar automaticamente todos os documentos cont&iacute;dos no diret&oacute;rio @upload@.',
'info_installer_ftp' => 'Como administrador, voc&ecirc; pode transferir (por FTP) arquivos para o diret&oacute;rio @upload@ para, em seguida, selecion&aacute;-los aqui diretamente.',
'info_installer_images' => 'Voc&ecirc; pode transferir imagens nos formatos JPEG, GIF e PNG.',
'info_installer_images_dossier' => 'Transferir as imagens para o diret&oacute;rio @upload@ para poder selecion&aacute;-las aqui.',
'info_installer_tous_documents' => 'Instalar todos os documentos',
'info_interface_complete' => 'interface completa',
'info_interface_simple' => 'Interface simplificada',
'info_joindre_document_article' => 'Voc&ecirc; pode anexar a esta mat&eacute;ria documentos dos tipos a seguir',
'info_joindre_document_rubrique' => 'Voc&ecirc; pode anexar a esta se&ccedil;&atilde;o documentos dos tipos a seguir',
'info_joindre_documents_article' => 'Voc&ecirc; pode anexar &agrave; sua mat&eacute;ria documentos dos tipos a seguir:',
'info_l_article' => 'a mat&eacute;ria',
'info_la_breve' => 'a nota',
'info_la_rubrique' => 'a se&ccedil;&atilde;o',
'info_langue_principale' => 'Idioma principal do site',
'info_largeur_vignette' => '@largeur_vignette@ &times; @hauteur_vignette@ pixels',
'info_les_auteurs_1' => 'por @les_auteurs@',
'info_logo_format_interdit' => 'Apenas os &iacute;cones nos formatos @formats@ est&atilde;o autorizados.',
'info_logo_max_poids' => 'Os &iacute;cones devem obrigatoriamente ter menos de @maxi@ (este arquivo tem @actuel@).',
'info_logo_max_taille' => 'Os &iacute;cones devem obrigatoriamente ter menos de @maxi@ (este arquivo tem @actuel@).',
'info_mail_fournisseur' => 'voce@seudominio.com.br',
'info_message_2' => 'MENSAGEM',
'info_message_supprime' => 'MENSAGEM EXCLU&Iacute;DA',
'info_messages_nb' => '@nb@ mensagens',
'info_messages_un' => '1 mensagem',
'info_mise_en_ligne' => 'Data de publica&ccedil;&atilde;o online:',
'info_modification_parametres_securite' => 'modifica&ccedil;&otilde;es dos par&acirc;metros de seguran&ccedil;a',
'info_mois_courant' => 'No m&ecirc;s corrente:',
'info_mot_cle_ajoute' => 'A palavra-chave a seguir foi associada a',
'info_multi_herit' => 'Idioma padr&atilde;o',
'info_multi_langues_soulignees' => 'Os <u>idiomas sublinhados</u> possuem tradu&ccedil;&atilde;o para todos os textos da interface. Se voc&ecirc; escolher esses idiomas, diversos elementos do site p&uacute;blico (datas, formul&aacute;rios) s&atilde;o traduzidos automaticamente. Para os idiomas n&atilde;o sublinhados, estes elementos aparecer&atilde;o no idioma principal do site.',
'info_multilinguisme' => 'Multilinguismo',
'info_nom_non_utilisateurs_connectes' => 'Seu nome n&atilde;o aparece na rela&ccedil;&atilde;o de usu&aacute;rios conectados.',
'info_nom_utilisateurs_connectes' => 'Seu nome aparecer&aacute; na rela&ccedil;&atilde;o de usu&aacute;rios conectados.',
'info_nombre_en_ligne' => 'Online neste momento:',
'info_non_resultat' => 'Nenhum resultados para "@cherche_mot@"',
'info_non_utilisation_messagerie' => 'Voc&ecirc; n&atilde;o utiliza o sistema de mensagens deste site.',
'info_nouveau_message' => 'VOC&Ecirc; TEM UMA NOVA MENSAGEM',
'info_nouveaux_messages' => 'VOC&Ecirc; TEM @total_messages@ MENSAGENS NOVAS',
'info_numero_abbreviation' => 'N&deg;&nbsp;',
'info_obligatoire' => 'Esta informa&ccedil;&atilde;o &eacute; obrigat&oacute;ria',
'info_panne_site_syndique' => 'Site sindicado com problemas',
'info_pense_bete' => 'LEMBRETE',
'info_petit_ecran' => 'Baixa resolu&ccedil;&atilde;o',
'info_petition_close' => 'Peti&ccedil;&atilde;o fechada',
'info_pixels' => 'pixels',
'info_plusieurs_mots_trouves' => 'V&aacute;rias palavras-chave encontradas para "@cherche_mot@":',
'info_popularite_5' => 'popularidade:',
'info_portfolio' => 'Portf&oacute;lio',
'info_portfolio_automatique' => 'Portf&oacute;lio autom&aacute;tico:',
'info_premier_resultat' => '[@debut_limit@ primeiros resultados de @total@]',
'info_premier_resultat_sur' => '[@debut_limit@ primeiros resultados de @total@]',
'info_probleme_grave' => 'problema de',
'info_propose_1' => '[@nom_site_spip@] Prop&otilde;e: @titre@',
'info_propose_2' => 'Mat&eacute;ria proposta
----------------',
'info_propose_3' => 'A mat&eacute;ria "@titre@" foi proposta para publica&ccedil;&atilde;o.',
'info_propose_4' => 'Voc&ecirc; est&aacute; convidado a consult&aacute;-la e dar sua opini&atilde;o',
'info_propose_5' => 'no f&oacute;rum a ela anexado. Ela est&aacute; dispon&iacute;vel no endere&ccedil;o:',
'info_publie_01' => 'A mat&eacute;ria "@titre@" foi validada por @connect_nom@.',
'info_publie_1' => '[@nom_site_spip@] PUBLICADO: @titre@',
'info_publie_2' => 'Mat&eacute;ria publicada
-----------------',
'info_rechercher' => 'Procurar',
'info_rechercher_02' => 'Procurar:',
'info_remplacer_vignette' => 'Substituir o &iacute;cone padr&atilde;o por um logo personalizado:',
'info_retablir_lien' => 'reabilitar este link',
'info_retirer_mot' => 'Retirar esta palavra-chave',
'info_retirer_mots' => 'Retirar todas as palavras-chave',
'info_rubriques_nb' => '@nb@ se&ccedil;&otilde;es',
'info_rubriques_un' => '1 se&ccedil;&atilde;o',
'info_sans_titre_2' => 'sem t&iacute;tulo',
'info_selectionner_fichier' => 'Voc&ecirc; pode escolher um arquivo do diret&oacute;rio @upload@',
'info_selectionner_fichier_2' => 'Selecionar um arquivo:',
'info_signature_supprimee' => 'Assinatura exclu&iacute;da',
'info_signature_supprimee_erreur' => 'Erro: este c&oacute;digo de exclus&atilde;o n&atilde;o corresponde a nenhuma assinatura',
'info_site_attente' => 'Website aguardando valida&ccedil;&atilde;o',
'info_site_reference' => 'Site referenciado online',
'info_site_refuse' => 'Website recusado',
'info_sites_nb' => '@nb@ sites',
'info_sites_referencer' => 'Referenciar um site',
'info_sites_un' => '1 site',
'info_supprimer_vignette' => 'excluir o &iacute;cone',
'info_symbole_bleu' => 'O &iacute;cone <b>azul</b> indica um <b>lembrete</b>: ou seja, uma mensagem para seu uso pessoal.',
'info_symbole_jaune' => 'O &iacute;cone <b>amarelo</b> indica um  <b>an&uacute;ncio para todos os redatores</b>: modific&aacute;vel por todos os administradores, e vis&iacute;vel por todos os redatores.',
'info_symbole_vert' => 'O &iacute;cone <b>verde</b> indica as  <b>mensagens trocadas com outros usu&aacute;rios</b> do site.',
'info_syndication' => 'sindica&ccedil;&atilde;o:',
'info_syndication_articles' => 'mat&eacute;ria(s)',
'info_telecharger' => 'Transferir do seu computador:',
'info_telecharger_nouveau_logo' => 'Transferir um novo logo:',
'info_telecharger_ordinateur' => 'Tranferir do seu computador:',
'info_tous_resultats_enregistres' => '[todos os resultados s&atilde;o gravados]',
'info_tout_afficher' => 'Mostrar todas',
'info_travaux_texte' => 'Este site ainda n&atilde;o est&aacute; configurado. Volte mais tarde...',
'info_travaux_titre' => 'Site em manuten&ccedil;&atilde;o',
'info_trop_resultat' => 'Resultados de mais para "@cherche_mot@"; por favor, refine a busca.',
'info_utilisation_messagerie_interne' => 'Voc&ecirc; usa o sistema interno de mensagens deste site.',
'info_valider_lien' => 'validar este link',
'info_verifier_image' => ', verifique se as suas imagens foram transferidas corretamente.',
'info_vignette_defaut' => '&Iacute;cone padr&atilde;o',
'info_vignette_personnalisee' => '&Iacute;cone personalizado',
'info_visite' => 'visita:',
'info_visites' => 'visitas:',
'info_vos_rendez_vous' => 'Seus encontros futuros',
'info_zoom' => 'zoom',
'infos_vos_pense_bete' => 'Seus lembretes',
'item_breve_proposee' => 'Nota proposta',

// L
'lien_afficher_icones_seuls' => 'Exibir apenas os &iacute;cones',
'lien_afficher_texte_icones' => 'Exibir &iacute;cones e texto',
'lien_afficher_texte_seul' => 'Exibir apenas o texto',
'lien_liberer' => 'liberar',
'lien_liberer_tous' => 'liberar estas mat&eacute;rias',
'lien_nouvea_pense_bete' => 'NOVO LEMBRETE',
'lien_nouveau_message' => 'NOVA MENSAGEM',
'lien_nouvelle_annonce' => 'NOVO AN&Uacute;NCIO',
'lien_petitions' => 'PETI&Ccedil;&Atilde;O',
'lien_popularite' => 'popularidade: @popularite@%',
'lien_racine_site' => 'RAIZ DO SITE',
'lien_reessayer' => 'tente novamente',
'lien_repondre_message' => 'Responder a esta mensagem',
'lien_supprimer' => 'excluir',
'lien_tout_afficher' => 'Mostrar tudo',
'lien_visite_site' => 'visitar este site',
'lien_visites' => '@visites@&nbsp;visitas',
'lien_voir_auteur' => 'Ver este autor',
'ligne' => 'Linha',
'login' => 'Conex&atilde;o',
'login_acces_prive' => 'acesso ao espa&ccedil;o privado',
'login_autre_identifiant' => 'conectar-se com outra identifica&ccedil;&atilde;o',
'login_cookie_accepte' => 'Por favor, configure o seu navegador para aceit&aacute;-los (pelo menos para este site).',
'login_cookie_oblige' => 'Para voc&ecirc; se identificar de modo seguro neste site, voc&ecirc; precisa aceitar cookies.',
'login_deconnexion_ok' => 'Desconex&atilde;o efetuada.',
'login_erreur_pass' => 'Erro de senha.',
'login_espace_prive' => 'espa&ccedil;o privado',
'login_identifiant_inconnu' => 'O identificador &laquo; @login@ &raquo; n&atilde;o est&aacute; cadastrado.',
'login_login' => 'Login:',
'login_login2' => 'Login (identificador para conex&atilde;o ao site):',
'login_login_pass_incorrect' => '(Login ou senha incorreta.)',
'login_motpasseoublie' => 'esqueceu&nbsp;sua&nbsp;senha?',
'login_non_securise' => 'Aten&ccedil;&atilde;o, este formul&aacute;rio n&atilde;o &eacute; seguro.
Se voc&ecirc; n&atilde;o quiser que a sua senha possa ser interceptada na rede, por favor ative o Javascript no seu navegador e',
'login_nouvelle_tentative' => 'Tentar novamente',
'login_par_ici' => 'Voc&Ecirc; est&aacute; registrado... por aqui...',
'login_pass2' => 'Senha:',
'login_preferez_refuser' => '<b>Se voc&ecirc; prefere recusar os cookies</b>, um outro m&eacute;todo de conex&atilde;o (menos seguro) est&aacute; dispon&iacute;vel:',
'login_recharger' => 'atualizar esta p&aacute;gina',
'login_rester_identifie' => 'Manter-se identificado por alguns dias',
'login_retour_public' => 'Voltar ao site p&uacute;blico',
'login_retour_site' => 'Voltar ao site p&uacute;blico',
'login_retoursitepublic' => 'voltar&nbsp;ao&nbsp;site&nbsp;p&uacute;blico',
'login_sans_cookiie' => 'Identifica&ccedil;&atilde;o sem cookie',
'login_securise' => 'Login seguro',
'login_sinscrire' => 'cadastrar-se',
'login_test_navigateur' => 'testar navegador/reconex&atilde;o',
'login_verifiez_navigateur' => '(Verifique sempre se o seu navegador n&atilde;o est&aacute; memorizando a sua senha...)',

// M
'masquer_colonne' => 'Ocultar esta coluna',
'masquer_trad' => 'esconder as tradu&ccedil;&otilde;es',
'module_fichiers_langues' => 'Arquivos de idioma',

// N
'navigateur_pas_redirige' => 'Se o seu navegador n&atilde;o o redirecionar, clique aqui para continuar.',
'numero' => 'N&uacute;mero',

// O
'occurence' => 'Ocorr&ecirc;ncia',
'onglet_affacer_base' => 'Apagar a base',
'onglet_auteur' => 'O autor',
'onglet_contenu_site' => 'Conte&uacute;do do site',
'onglet_evolution_visite_mod' => 'Evolu&ccedil;&atilde;o',
'onglet_fonctions_avances' => 'Fun&ccedil;&otilde;es avan&ccedil;adas',
'onglet_informations_personnelles' => 'Informa&ccedil;&otilde;es pessoais',
'onglet_interactivite' => 'Interatividade',
'onglet_messagerie' => 'Sistema de mensagens',
'onglet_messages_internes' => 'Mensagens internas',
'onglet_messages_publics' => 'Mensagens p&uacute;blicas',
'onglet_messages_vide' => 'Mensagens sem texto',
'onglet_origine_visites' => 'Origem das visitas',
'onglet_repartition_debut' => 'desde o in&iacute;cio',
'onglet_repartition_lang' => 'Reparti&ccedil;&atilde;o por idiomas',
'onglet_repartition_rubrique' => 'Reparti&ccedil;&atilde;o por se&ccedil;&otilde;es',
'onglet_save_restaur_base' => 'Fazer c&oacute;pia de seguran&ccedil;a/restaurar a base',
'onglet_vider_cache' => 'Esvaziar o cache',
'ortho_trop_de_fautes2' => 'Comece corrigindo os erros mais &oacute;bvios e tente novamente.',

// P
'pass_choix_pass' => 'Por favor, escolha a sua nova senha:',
'pass_erreur' => 'Erro',
'pass_erreur_acces_refuse' => '<b>Erro:</b> voc&ecirc; n&atilde;o tem mais acesso a este site.',
'pass_erreur_code_inconnu' => '<b>Erro:</b> este login n&atilde;o corresponde a nenhum visitante com permiss&atilde;o de acesso a este site.',
'pass_erreur_non_enregistre' => '<b>Erro:</b> o e-mail <tt>@email_oubli@</tt> n&atilde;o est&aacute; cadastrado neste site.',
'pass_erreur_non_valide' => '<b>Erro:</b> o e-mail <tt>@email_oubli@</tt> n&atilde;o &eacute; v&aacute;lido!',
'pass_erreur_probleme_technique' => '<b>Erro:</b> este e-mail n&atilde;o p&ocirc;de ser enviado devido a um problema t&eacute;cnico.',
'pass_espace_prive_bla' => 'O espa&ccedil;o privado deste site &eacute; aberto aos visitantes, ap&oacute;s inscri&ccedil;&atilde;o. Uma vez cadastrado, voc&ecirc; poder&aacute; consultar as mat&eacute;rias em fase de reda&ccedil;&atilde;o, propor a publica&ccedil;&atilde;o de novas mat&eacute;rias e participar de todos os f&oacute;runs.',
'pass_forum_bla' => 'Voc&ecirc; soliciou a participa&ccedil;&atilde;o num f&oacute;rum reservado a visitantes registrados.',
'pass_indiquez_cidessous' => 'Informe abaixo o endere&ccedil;o de e-mail com o qual voc&ecirc; se cadastrou anteriormente. Voc&ecirc; receber&aacute; um e-mail lhe indicando os procedimentos a seguir para recuperar o seu acesso.',
'pass_mail_passcookie' => '(esta &eacute; uma mensagem autom&aacute;tica)
Para recuperar o seu acesso ao site
@nom_site_spip@ (@adresse_site@)

clique por favor no endere&ccedil;o a seguir:

    @sendcookie@

Voc&ecirc; poder&aacute; ent&atilde;o cadastrar uma nova senha
e reconectar-se com o site.

',
'pass_mot_oublie' => 'Senha esquecida',
'pass_nouveau_enregistre' => 'Sua nova senha foi cadastrada.',
'pass_nouveau_pass' => 'Nova senha',
'pass_ok' => 'OK',
'pass_oubli_mot' => 'Esquecimento de senha',
'pass_quitter_fenetre' => 'Fechar esta janela',
'pass_rappel_login' => 'Lembrete: seu login &eacute; &laquo;@login@&raquo;.',
'pass_recevoir_mail' => 'Voc&ecirc; receber&aacute; um e-mail explicando como voc&ecirc; pode recuperar o acesso ao site.',
'pass_retour_public' => 'Voltar para o site p&uacute;blico',
'pass_rien_a_faire_ici' => 'Nada a fazer aqui.',
'pass_vousinscrire' => 'Cadastrar-se neste site',
'precedent' => 'precedente',
'previsualisation' => 'Visualiza&ccedil;&atilde;o',
'previsualiser' => 'Visualizar',

// R
'retour' => 'Voltar',

// S
'spip_conforme_dtd' => 'O SPIP considera este documento de acordo com o seu DOCTYPE:',
'squelette' => 'esqueleto',
'squelette_inclus_ligne' => 'esqueleto inclu&iacute;do, linha',
'squelette_ligne' => 'esqueleto, linha',
'stats_visites_et_popularite' => '@visites@ visitas; popularidade: @popularite@',
'suivant' => 'seguinte',

// T
'taille_ko' => '@taille@&nbsp;KB',
'taille_mo' => '@taille@&nbsp;MB',
'taille_octets' => ' @taille@&nbsp;bytes',
'texte_actualite_site_1' => 'Quando voc&ecirc; estiver mais familiarizado com a interface, clique em &laquo;',
'texte_actualite_site_2' => 'interface completa',
'texte_actualite_site_3' => '&raquo; para abrir mais possibilidades.',
'texte_creation_automatique_vignette' => 'A cria&ccedil;&atilde;o autom&aacute;tica de &iacute;cones de visualiza&ccedil;&atilde;o est&aacute; ativada neste site. Se voc&ecirc; transferir por este formul&aacute;rio imagens no(s) formato(s) @gd_formats@, elas ser&atilde;o acompanhadas de um &iacute;cone com o tamanho m&aacute;ximo de @taille_preview@&nbsp;pixels.',
'texte_documents_associes' => 'Os documentos a seguir est&atilde;o associados &agrave; mat&eacute;ria,
mas eles n&atilde;o foram inseridos diretamente. Dependendo da elabora&ccedil;&atilde;o dos gabaritos do site p&uacute;blico, eles podem aparecer como documentos anexados.',
'texte_erreur_mise_niveau_base' => 'Erro da base de dados durante a atualiza&ccedil;&atilde;o.
A imagem <b>@fichier@</b> n&atilde;o passou (mat&eacute;ria @id_article@).
Anote esta refer&ecirc;ncia, tente novamente a atualiza&ccedil;&atilde;o e, finalmente, verifique se as imagens aparecem nas mat&eacute;rias.',
'texte_erreur_visiteur' => 'Voc&ecirc; tentou acessar o espa&ccedil;o restrito com um login que n&atilde;o tem a permiss&atilde;o necess&aacute;ria.',
'texte_inc_auth_1' => 'Voc&ecirc; se identificou com o login <b>@auth_login@</b>, mas ele n&atilde;o consta (mais) na base.
Tente se',
'texte_inc_auth_2' => 'reconectar',
'texte_inc_auth_3' => ', ap&oacute;s ter eventualmente sa&iacute;do e reiniciado o seu navegador.',
'texte_inc_config' => 'As modifica&ccedil;&otilde;es efetuadas nestas p&aacute;ginas influem consideravelmente no funcionamento do seu site. &Eacute; recomend&aacute;vel n&atilde;o intervir enquanto voc&ecirc; n&atilde;o estiver familiarizado com o funcionamento do sistema SPIP.<br /><br /><b>Geralmente, &eacute; fortemente aconselh&aacute;vel deixar a carga destas p&aacute;ginas para o webmaster principal do seu site.</b>',
'texte_inc_meta_1' => 'O sistema encontrou um erro durante a escrita do arquivo <code>@fichier@</code>. Como administrador do site, queira por favor,',
'texte_inc_meta_2' => 'Verificar os direitos de escrita',
'texte_inc_meta_3' => 'no diret&oacute;rio <code>@repertoire@</code>.',
'texte_statut_en_cours_redaction' => 'em fase de reda&ccedil;&atilde;o',
'texte_statut_poubelle' => 'na lixeira',
'texte_statut_propose_evaluation' => 'proposto para avalia&ccedil;&atilde;o',
'texte_statut_publie' => 'publicado online',
'texte_statut_refuse' => 'recusado',
'titre_ajouter_mot_cle' => 'INCLUIR UMA PALAVRA-CHAVE:',
'titre_breve_proposee' => 'Nota proposta',
'titre_breve_publiee' => 'Nota publicada',
'titre_breve_refusee' => 'Nota recusada',
'titre_cadre_raccourcis' => 'ATALHOS:',
'titre_changer_couleur_interface' => 'Alterar a c&ocirc;r da interface',
'titre_forum' => 'F&oacute;rum',
'titre_image_admin_article' => 'Voc&ecirc; pode administrar esta mat&eacute;ria',
'titre_image_administrateur' => 'Administrador',
'titre_image_aide' => 'Ajuda sobre este elemento',
'titre_image_auteur_supprime' => 'Autor exclu&iacute;do',
'titre_image_redacteur' => 'Redator sem acesso',
'titre_image_redacteur_02' => 'Redator',
'titre_image_visiteur' => 'Visitante',
'titre_joindre_document' => 'INCLUIR UM DOCUMENTO',
'titre_liens_entrants' => 'Links de entrada',
'titre_mots_cles' => 'PALAVRAS-CHAVE',
'titre_probleme_technique' => 'Aten&ccedil;&atilde;o: um problema t&eacute;cnico (servidor SQL) impede o acesso a esta parte do site. Obrigado por sua compreen&ccedil;&atilde;o.',
'titre_publier_document' => 'PUBLICAR UM DOCUMENTO NESTA SE&Ccedil;&Atilde;O',
'titre_signatures_attente' => 'Assinaturas aguardando valida&ccedil;&atilde;o',
'titre_signatures_confirmees' => 'Assinaturas confirmadas',
'titre_statistiques' => 'Estat&iacute;sticas do site',
'titre_titre_document' => 'T&iacute;tulo do documento:',
'todo' => 'breve',
'trad_reference' => '(mat&eacute;ria de refer&ecirc;ncia)',

// Z
'zbug_balise_b_aval' => ': tag B colocada ap&oacute;s BOUCLE',
'zbug_balise_inexistante' => 'Tag @balise@ mal declarada para @from@',
'zbug_balise_sans_argument' => 'Falta um arqumento na tag @balise@',
'zbug_boucle' => 'la&ccedil;o',
'zbug_boucle_recursive_undef' => 'La&ccedil;o recursivo n&atilde;o definido: @nom@',
'zbug_calcul' => 'c&aacute;lculo',
'zbug_champ_hors_boucle' => 'Campo @champ@ fora do la&ccedil;o',
'zbug_champ_hors_motif' => 'Campo @champ@ fora de um contexto @motif@',
'zbug_code' => 'c&oacute;digo',
'zbug_critere_inconnu' => 'Crit&eacute;rio @critere@ desconhecido',
'zbug_distant_interdit' => 'Externa interdita',
'zbug_doublon_table_sans_cle_primaire' => 'Duplica&ccedil;&atilde;o em tabela sem chave prim&aacute;ria at&ocirc;mica',
'zbug_doublon_table_sans_index' => 'Doublons em uma tabela sem index',
'zbug_erreur_boucle_double' => 'Dupla defini&ccedil;&atilde;o do la&ccedil;o @id@',
'zbug_erreur_boucle_fermant' => 'La&ccedil;o @id@ n&atilde;o fechado',
'zbug_erreur_boucle_syntaxe' => 'Sintaxe do la&ccedil;o @id@ est&aacute; incorreta',
'zbug_erreur_compilation' => 'Erro de compila&ccedil;&atilde;o',
'zbug_erreur_execution_page' => 'Erro de execu&ccedil;&atilde;o',
'zbug_erreur_filtre' => 'Filtro @filtre@ n&atilde;o definido',
'zbug_erreur_meme_parent' => 'O crit&eacute;rio {meme_parent} aplica-se exclusivamente aos la&ccedil;os (FORUMS) ou (RUBRIQUES)',
'zbug_erreur_squelette' => 'Erro(s) no gabarito',
'zbug_hors_compilation' => 'Fora de Compila&ccedil;&atilde;o',
'zbug_info_erreur_squelette' => 'Erro no site',
'zbug_inversion_ordre_inexistant' => 'Invers&atilde;o de uma ordem inexistente',
'zbug_pagination_sans_critere' => 'Tag #PAGINATION sem crit&eacute;rio {pagination} ou usada dentro de uma boucle recursiva',
'zbug_parametres_inclus_incorrects' => 'Par&acirc;metro de inclus&atilde;o incorreto: @param@',
'zbug_profile' => 'Tempo de processamento: @time@',
'zbug_resultat' => 'resultado',
'zbug_serveur_indefini' => 'Sevidor SQL n&atilde;o definido',
'zbug_statistiques' => 'Estat&iacute;sticas das requisi&ccedil;&otilde;es SQL classificadas por dura&ccedil;&atilde;o',
'zbug_table_inconnue' => 'Tabela SQL &laquo;@table@&raquo; desconhecida',
'zxml_connus_attributs' => 'atributos conhecidos',
'zxml_de' => 'de',
'zxml_inconnu_attribut' => 'atributo desconhecido',
'zxml_inconnu_balise' => 'tag desconhecida',
'zxml_inconnu_entite' => 'entidade desconhecida',
'zxml_inconnu_id' => 'ID desconhecida',
'zxml_mais_de' => 'mas de',
'zxml_non_conforme' => 'n&atilde;o est&aacute; de acordo com o motivo',
'zxml_non_fils' => 'n&atilde;o &eacute; filho de',
'zxml_nonvide_balise' => 'tag n&atilde;o vazia',
'zxml_obligatoire_attribut' => 'atributo obrigat&oacute;rio mas ausente em',
'zxml_succession_fils_incorrecte' => 'sucess&atilde;o de filhos incorreta',
'zxml_survoler' => 'sobrepor para ver os corretos',
'zxml_valeur_attribut' => 'valor do atributo',
'zxml_vide_balise' => 'tag vazia',
'zxml_vu' => 'previsualiza&ccedil;&atilde;o'
);

?>
